Progress.both constructor

Progress.both(
  1. LineAction both, {
  2. Encoding encoding = utf8,
})

redirect both stdout and stderr to the same LineAction Note: to capture stderr you must pass 'throws: false' to the start process method. Use encoding to control how output bytes are decoded into strings.

Implementation

factory Progress.both(LineAction both, {Encoding encoding = utf8}) =>
    ProgressBothImpl(both, stderr: both, encoding: encoding);